@@ -12,7 +12,9 @@ geom_flag <- function(mapping=NULL, data=NULL, inherit.aes=TRUE,
 }
 
 flag <- function(flag) {
-    paste0('https://behdad.github.io/region-flags/png/', toupper(flag), ".png")
+    url <- paste0('https://behdad.github.io/region-flags/png/', toupper(flag), ".png")
+
+    check_url(url)
 }
 
 
